diff src/http/ngx_http_output_filter.c @ 91:637625a2acdb

nginx-0.0.1-2003-05-19-20:39:14 import
author Igor Sysoev <igor@sysoev.ru>
date Mon, 19 May 2003 16:39:14 +0000
parents 37530da31268
children 8220378432a8
line wrap: on
line diff
--- a/src/http/ngx_http_output_filter.c
+++ b/src/http/ngx_http_output_filter.c
@@ -23,7 +23,7 @@ static void ngx_http_output_filter_init(
 static ngx_command_t  ngx_http_output_filter_commands[] = {
 
     {ngx_string("output_buffer"),
-     NGX_HTTP_LOC_CONF|NGX_CONF_TAKE1,
+     NGX_HTTP_MAIN_CONF|NGX_HTTP_SRV_CONF|NGX_HTTP_LOC_CONF|NGX_CONF_TAKE1,
      ngx_conf_set_size_slot,
      NGX_HTTP_LOC_CONF_OFFSET,
      offsetof(ngx_http_output_filter_conf_t, hunk_size),
@@ -36,11 +36,14 @@ static ngx_command_t  ngx_http_output_fi
 static ngx_http_module_t  ngx_http_output_filter_module_ctx = {
     NGX_HTTP_MODULE,
 
-    NULL,                                  /* create server config */
-    NULL,                                  /* init server config */
+    NULL,                                  /* create main configuration */
+    NULL,                                  /* init main configuration */
 
-    ngx_http_output_filter_create_conf,    /* create location config */
-    ngx_http_output_filter_merge_conf      /* merge location config */
+    NULL,                                  /* create server configuration */
+    NULL,                                  /* merge server configuration */
+
+    ngx_http_output_filter_create_conf,    /* create location configuration */
+    ngx_http_output_filter_merge_conf      /* merge location configuration */
 };
 
 
@@ -336,7 +339,7 @@ static char *ngx_http_output_filter_merg
     ngx_http_output_filter_conf_t *conf =
                                        (ngx_http_output_filter_conf_t *) child;
 
-    ngx_conf_size_merge(conf->hunk_size, prev->hunk_size, 32768);
+    ngx_conf_merge_size_value(conf->hunk_size, prev->hunk_size, 32768);
 
     return NULL;
 }